#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


accountEndpoint = "/identity/v2/manage/account/"

class CustomObject:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def create(self, uid, objectName, payload):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret() + '&objectname='  +objectName
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/customobject?" + params
        return self._lr_object._post_json(url, payload)
    
    def update(self, uid, objectRecordId, objectName, payload, updatetype = 'partialreplace'):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret() + '&objectname='  +objectName + '&updatetype=' + updatetype
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/customobject/"+objectRecordId+"?" + params
        return self._lr_object._put_json(url, payload)
    
    def getByUID(self, uid, objectName):
        """Token Validate( GET )"""
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'objectname':objectName}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/customobject"
        return self._lr_object._get_json(url, payload)
    
    def getByObjectRecordId(self, uid, objectRecordId, objectName):
        """Token Validate( GET )"""
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'objectname':objectName}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/customobject/" +objectRecordId
        return self._lr_object._get_json(url, payload)

    def remove(self, uid, objectRecordId, objectName):
        """Account Delete( DELETE )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret() +'&objectname='  +objectName
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/customobject/" + objectRecordId + "?" + params
        return self._lr_object._delete_json(url, {})



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


roleEndpoint = "/identity/v2/manage/";

class Role:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def create(self, payload):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + roleEndpoint  + "role?" + params
        return self._lr_object._post_json(url, payload)
    
    def get(self):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + roleEndpoint  + "role"
        return self._lr_object._get_json(url, payload)
    
    def remove(self, role):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + roleEndpoint  + "role/"+role +"?" + params
        return self._lr_object._delete_json(url, {})
    
    def unassignRoles(self, uid, rolePayload):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/"+ uid + "/role" + "?" + params
        return self._lr_object._delete_json(url, rolePayload)

    class Permission:
        def __init__(self, lr_object):
            """
            :param lr_object: this is the reference to the parent LoginRadius object.
            """
            self._lr_object = lr_object

        def add(self, role, payload):
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "role/" +role+ "/permission?" + params
            return self._lr_object._put_json(url, payload)
    
        def remove(self, role, payload):
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "role/" +role+ "/permission?" + params
            return self._lr_object._delete_json(url, payload)

    class Context:
        def __init__(self, lr_object):
            """
            :param lr_object: this is the reference to the parent LoginRadius object.
            """
            self._lr_object = lr_object

        def get(self, uid):
            """Get Context with Roles and Permissions( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret()}
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/" +uid+ "/rolecontext"
            return self._lr_object._get_json(url, payload)
    
        def add(self, uid, payload):
            """Add/Update Role Context with  Roles and Permissions( PUT )"""
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/" +uid+ "/rolecontext?" + params
            return self._lr_object._put_json(url, payload)

        def delete(self, uid, rolecontextname):
            """Delete Role Context( DELETE )"""
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/" +uid+ "/rolecontext/" +rolecontextname+ "/?" + params
            return self._lr_object._delete_json(url, {})

        def deleteRole(self, uid, rolecontextname, rolenamePayload):
            """Delete Role Context( DELETE )"""
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/" +uid+ "/rolecontext/" +rolecontextname+ "/role?" + params
            return self._lr_object._delete_json(url, rolenamePayload)

        def deletePermission(self, uid, rolecontextname, additionalpermissionPayload):
            """Delete Role Context( DELETE )"""
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
            url = self._lr_object.SECURE_API_URL + roleEndpoint  + "account/" +uid+ "/rolecontext/" +rolecontextname+ "/additionalpermission?" + params
            return self._lr_object._delete_json(url, additionalpermissionPayload) 
        



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


authEndpoint = "identity/v2/auth/"

class Authentication:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def register(self, payload, verificationUrl = '', emailTemplate = '', getLRServerTime = False):
        """User Registration( POST )"""
        from LoginRadius.sdk.sott import SOTT
        sottAPI = SOTT(self._lr_object)
        
        sott = sottAPI.encrypt('10', getLRServerTime)
        params = 'apikey='+self._lr_object._get_api_key() +'&sott='+sott+'&verificationUrl='+verificationUrl+'&emailTemplate='+emailTemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint + "register" + "?" + params
        return self._lr_object._post_json(url, payload)

    def getServerTime(self, timeDifference):
        if timeDifference != '':
            timeDifference = '10';
        payload = {'apikey': self._lr_object._get_api_key(), 'timedifference':timeDifference}
        url = self._lr_object.SECURE_API_URL  +  "identity/v2/serverinfo"
        return self._lr_object._get_json(url, payload)
    
    def captchaRegister(self, payload, verificationUrl = '', emailTemplate = ''):
        params = 'apikey='+self._lr_object._get_api_key() +'&verificationUrl='+verificationUrl+'&emailTemplate='+emailTemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint + "register/captcha" + "?" + params
        return self._lr_object._post_json(url, payload)
    
    def resendEmailVerification(self, email, verificationUrl = '', emailTemplate = ''):
        """Resend Email Verification( PUT )"""
        payload ={'email':email}
        params = 'apikey='+self._lr_object._get_api_key() +'&verificationUrl='+verificationUrl+'&emailTemplate='+emailTemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "register" + "?" + params
        return self._lr_object._put_json(url, payload)
    
    def removeAccountByEmailConfirmation(self, access_token, deleteUrl = '', emailTemplate = ''):
        """Delete Account With Email Confirmation( DELETE )"""
        params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&verificationUrl='+deleteUrl+'&emailTemplate='+emailTemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "account" + "?" + params
        return self._lr_object._delete_json(url, {})
    
    def forgotPassword(self, email, resetPasswordUrl, emailTemplate = ''):
        """Forgot Password( POST )"""
        payload ={'email':email}
        params = 'apikey='+self._lr_object._get_api_key() +'&resetPasswordUrl='+resetPasswordUrl+'&emailTemplate='+emailTemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint + "password" + "?" + params
        return self._lr_object._post_json(url, payload)
    
    def resetPassword(self, resettoken, password):
        """Reset Password( PUT )"""
        payload ={'resettoken':resettoken, 'password':password}
        params = 'apikey='+self._lr_object._get_api_key()
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "password" + "?" + params
        return self._lr_object._put_json(url, payload)

    def resetPasswordbySecurityQuestion(self, securityanswer, userid, password):
        """Reset Password( PUT ) By SecurityQuestion"""
        payload ={'securityanswer':securityanswer, 'userid':userid, 'password':password}
        params = 'apikey='+self._lr_object._get_api_key()
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "password/securityanswer" + "?" + params
        return self._lr_object._put_json(url, payload)

    def updateSecurityQuestionByAccessToken(self, access_token, payload):
        """Update Security Question by Access_token( PUT )"""
        params = 'apikey='+self._lr_object._get_api_key()+'&access_token='+ access_token
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "account?" + params
        return self._lr_object._put_json(url, payload)
    
    def changePassword(self, access_token, oldpassword, newpassword):
        """Change Password( PUT )"""
        payload ={'oldpassword':oldpassword, 'newpassword':newpassword}
        params = 'apikey='+self._lr_object._get_api_key()+'&access_token='+ access_token
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "password" + "?" + params
        return self._lr_object._put_json(url, payload)
    
    def addEmail(self, access_token, email, emailtype, verificationUrl = '', emailTemplate = ''):
        """Add Email( POST )"""
        payload ={'email':email,'type':emailtype}
        params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&emailTemplate='+emailTemplate+'&verificationUrl='+verificationUrl
        url = self._lr_object.SECURE_API_URL + authEndpoint + "email" + "?" + params
        return self._lr_object._post_json(url, payload)
    
    def removeEmail(self, access_token, deleteurl = '', emailtemplate = ''):
        """Delete Account With Email Confirmation( DELETE )"""
        params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&deleteurl='+deleteurl+'&emailtemplate='+ emailtemplate
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "account" + "?" + params
        return self._lr_object._delete_json(url, {})

    def getVerifyEmail(self, verificationToken, url = ''):
        payload = {'apikey': self._lr_object._get_api_key(), 'verificationToken':verificationToken, 'url':url}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'email'
        return self._lr_object._get_json(url, payload)
    
    def getCheckEmail(self, email):
        payload = {'apikey': self._lr_object._get_api_key(), 'email':email}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'email'
        return self._lr_object._get_json(url, payload)
    
    def changeUsername(self, access_token, username):
        """Change Username( PUT )"""
        payload ={'username':username}
        params = 'apikey='+self._lr_object._get_api_key()+'&access_token='+ access_token
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "username" + "?" + params
        return self._lr_object._put_json(url, payload)
    
    def checkUsername(self, username):
        payload = {'apikey': self._lr_object._get_api_key(), 'username':username}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'username'
        return self._lr_object._get_json(url, payload)
    
    def accountLink(self, access_token, candidateToken):
        """Change Username( PUT )"""
        payload ={'candidateToken':candidateToken}
        params = 'apikey='+self._lr_object._get_api_key()+'&access_token='+ access_token
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "socialIdentity" + "?" + params
        return self._lr_object._put_json(url, payload)

    def accountUnlink(self, access_token, provider, providerid):
        """Account Unlink( DELETE )"""
        payload ={'provider':provider, 'providerid':providerid}
        params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token
        url = self._lr_object.SECURE_API_URL + authEndpoint +  "socialIdentity" + "?" + params
        return self._lr_object._delete_json(url, payload)
    
    def getSocialProfile(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'socialIdentity'
        return self._lr_object._get_json(url, payload)

    def tokenValidate(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'access_token/validate'
        return self._lr_object._get_json(url, payload)
    
    def tokenInvalidate(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'access_token/invalidate'
        return self._lr_object._get_json(url, payload)

    def securityQuestionByToken(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'securityquestion/accesstoken'
        return self._lr_object._get_json(url, payload)
    
    def securityQuestionByEmail(self, email):
        payload = {'apikey': self._lr_object._get_api_key(), 'email':email}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'securityquestion/email'
        return self._lr_object._get_json(url, payload)

    def securityQuestionByUsername(self, username):
        payload = {'apikey': self._lr_object._get_api_key(), 'username':username}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'securityquestion/username'
        return self._lr_object._get_json(url, payload)

    def securityQuestionByPhone(self, phone):
        payload = {'apikey': self._lr_object._get_api_key(), 'phone':phone}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'securityquestion/phone'
        return self._lr_object._get_json(url, payload)

    def getBackupCode(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'account/2fa/backupcode'
        return self._lr_object._get_json(url, payload)

    def resetBackupCode(self, access_token):
        payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + authEndpoint + 'account/2fa/backupcode/reset'
        return self._lr_object._get_json(url, payload)

        
        


    class Login:

        def __init__(self, lr_object):
            self._lr_object = lr_object

        def byEmail(self, email, password, verificationUrl = '', loginUrl = '', emailTemplate = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'email':email, 'password':password, 'loginUrl':loginUrl, 'verificationUrl':verificationUrl,'emailTemplate':emailTemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login'
            return self._lr_object._get_json(url, payload)

        def byUsername(self, username, password, verificationUrl = '', loginUrl = '', emailTemplate = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'username':username, 'password':password, 'loginUrl':loginUrl, 'verificationUrl':verificationUrl,'emailTemplate':emailTemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login'
            return self._lr_object._get_json(url, payload)

        def byOTP(self, phone, otp, smstemplate = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'phone':phone, 'otp':otp, 'smstemplate':smstemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login'
            return self._lr_object._get_json(url, payload)

        def byBackupCode(self, secondfactorauthenticationtoken, backupcode):
            payload = {'apikey': self._lr_object._get_api_key(), 'secondfactorauthenticationtoken':secondfactorauthenticationtoken, 'backupcode':backupcode}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/2fa/backupcode'
            return self._lr_object._get_json(url, payload)

        def autoLoginByUsername(self, username, password, clientguid, autologinemailtemplate  = '', welcomeemailtemplate  = '', redirecturl  = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'clientguid':clientguid,'username':username, 'password':password, 'redirecturl':redirecturl , 'autologinemailtemplate':autologinemailtemplate,'welcomeemailtemplate':welcomeemailtemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/autologin'
            return self._lr_object._get_json(url, payload)

        def autoLoginByEmail(self, email, password, clientguid, autologinemailtemplate  = '', welcomeemailtemplate  = '', redirecturl  = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'clientguid':clientguid,'email':email, 'password':password, 'redirecturl':redirecturl , 'autologinemailtemplate':autologinemailtemplate,'welcomeemailtemplate':welcomeemailtemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/autologin'
            return self._lr_object._get_json(url, payload)

        def ping(self, clientguid):
            payload = {'apikey': self._lr_object._get_api_key(),'clientguid':clientguid}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/autologin/ping'
            return self._lr_object._get_json(url, payload)

        def oneClickSignInByEmail(self, email, oneclicksignintemplate   = '', verificationurl   = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'email':email, 'oneclicksignintemplate':oneclicksignintemplate , 'verificationurl':verificationurl}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/oneclicksignin'
            return self._lr_object._get_json(url, payload)

        def oneClickSignInByUsername(self, username, oneclicksignintemplate  = '', verificationurl  = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'username':username, 'oneclicksignintemplate':oneclicksignintemplate , 'verificationurl':verificationurl}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/oneclicksignin'
            return self._lr_object._get_json(url, payload)

        def oneClickSignInVerification(self, verificationtoken, welcomeemailtemplate = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'verificationtoken':verificationtoken, 'welcomeemailtemplate':welcomeemailtemplate}
            url = self._lr_object.SECURE_API_URL + authEndpoint + 'login/oneclickverify'
            return self._lr_object._get_json(url, payload)
        
    class Profile:
        
        def __init__(self, lr_object):
            self._lr_object = lr_object
            
        def getByToken(self, access_token):
            payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "account"
            return self._lr_object._get_json(url, payload)
        
        def updateByToken(self, access_token, payload, verificationUrl = '', emailTemplate = ''):
            """Resend Email Verification( PUT )"""
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&verificationUrl='+verificationUrl+'&emailTemplate='+emailTemplate
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "account" + "?" + params
            return self._lr_object._put_json(url, payload)
    
    class CustomObject:

        def __init__(self, lr_object):
            self._lr_object = lr_object

        def create(self, access_token, objectName, payload):
            """Create Custom Object By Access Token( POST )"""
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&objectName='+objectName
            url = self._lr_object.SECURE_API_URL + authEndpoint + "customobject" + "?" + params
            return self._lr_object._post_json(url, payload)

        def update(self, access_token, objectRecordId, objectName, payload, updatetype='partialreplace'):
            """Update Custom Object Data( PUT )"""
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&objectname='+objectName+'&updatetype='+updatetype
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "customobject/" + objectRecordId +"?" + params
            return self._lr_object._put_json(url, payload)
        
        def getByToken(self, access_token, objectName):
            payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token, 'objectname':objectName}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "customobject"
            return self._lr_object._get_json(url, payload)
        
        def getByID(self, access_token, objectRecordId, objectName):
            payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token, 'objectname':objectName}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "customobject/"+objectRecordId
            return self._lr_object._get_json(url, payload)
        
        def delete(self, access_token, objectRecordId, objectName):
            """Delete Custom Object Set( DELETE )"""
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token + '&objectname='+objectName
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "customobject/" +objectRecordId + "?" + params
            return self._lr_object._delete_json(url, {})

    class TwoFactor:
        def __init__(self, lr_object):
            self._lr_object = lr_object

        def byToken(self, access_token, smsTemplate2FA = ''):
            """Get 2FA by Token( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token, 'smsTemplate2FA':smsTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "account/2FA"
            return self._lr_object._get_json(url, payload)
        
        def phoneLogin(self, phone, password, loginUrl = '', verificationUrl = '', smsTemplate = '', smsTemplate2FA = ''):
            """Get 2FA Phone Login( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'phone':phone, 'password':password,'loginUrl':loginUrl,'verificationUrl':verificationUrl,'smsTemplate':smsTemplate,'smsTemplate2FA':smsTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "login/2FA"
            return self._lr_object._get_json(url, payload)
        
        def emailLogin(self, email, password, loginUrl = '', verificationUrl = '', emailTemplate = '', smsTemplate2FA = ''):
            """Get 2FA Phone Login( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'email':email, 'password':password,'loginUrl':loginUrl,'verificationUrl':verificationUrl,'emailTemplate':emailTemplate,'smsTemplate2FA':smsTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "login/2FA"
            return self._lr_object._get_json(url, payload)

        def usernameLogin(self, username, password, loginUrl = '', verificationUrl = '', emailTemplate = '', smsTemplate2FA = '', emailTemplate2FA = ''):
            """Get 2FA Phone Login( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'username':username, 'password':password,'loginUrl':loginUrl,'verificationUrl':verificationUrl,'emailTemplate':emailTemplate,'emailTemplate2FA':emailTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "login/2FA"
            return self._lr_object._get_json(url, payload)

        def updatePhone(self, secondFactorAuthenticationToken, phoneNo2FA, smsTemplate2FA = ''):
            """Update Custom Object Data( PUT )"""
            payload ={'phoneNo2FA':phoneNo2FA}
            params = 'apikey='+self._lr_object._get_api_key() +'&secondFactorAuthenticationToken='+secondFactorAuthenticationToken+'&smsTemplate2FA='+smsTemplate2FA
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "login/2FA"  +"?" + params
            return self._lr_object._put_json(url, payload)

        def verifyGoogleAuth(self, secondFactorAuthenticationToken, googleAuthenticatorCode, otp, smsTemplate2FA = ''):
            """Get 2FA Verify Google Authenticator Code OR OTP( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'secondFactorAuthenticationToken':secondFactorAuthenticationToken, 'googleAuthenticatorCode':googleAuthenticatorCode,'otp':otp,'smsTemplate2FA':smsTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "login/2FA/Verification"
            return self._lr_object._get_json(url, payload)
        
        def updatePhoneByToken(self, access_token, phoneNo2FA, smsTemplate2FA = ''):
            """Update Custom Object Data( PUT )"""
            payload ={'phoneNo2FA':phoneNo2FA}
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token+'&smsTemplate2FA='+smsTemplate2FA
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "account/2FA"  +"?" + params
            return self._lr_object._put_json(url, payload)
        
        def googleAuthByToken(self, access_token, googleAuthenticatorCode, otp, smsTemplate2FA = ''):
            """Get 2FA Verify Google Authenticator Code OR OTP( GET )"""
            payload = {'apikey': self._lr_object._get_api_key(), 'access_token':access_token, 'googleAuthenticatorCode':googleAuthenticatorCode,'otp':otp,'smsTemplate2FA':smsTemplate2FA}
            url = self._lr_object.SECURE_API_URL + authEndpoint + "account/2FA/Verification"
            return self._lr_object._get_json(url, payload)
            
        def removeAuthByToken(self, access_token, authenticator):
            """Delete Custom Object Set( DELETE )"""
            payload = {}
            payload[authenticator]= True
            params = 'apikey='+self._lr_object._get_api_key() +'&access_token='+access_token
            url = self._lr_object.SECURE_API_URL + authEndpoint +  "account/2FA/authenticator"  + "?" + params
            return self._lr_object._delete_json(url, payload)
        
        



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


accountEndpoint = "identity/v2/manage/account/"
archivedEndpoint = "/api/v2/identity/archived";

class Account:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def create(self, payload):
        """Create Account( POST )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + "?" + params
        return self._lr_object._post_json(url, payload)
            
    def update(self, uid, payload):
        """Create Account( POST )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "?" + params
        return self._lr_object._put_json(url, payload)
    
    def remove(self, uid):
        """Account Delete( DELETE )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "?" + params
        return self._lr_object._delete_json(url, {})
    
    def setPassword(self, uid, password):
        """Account Set Password( PUT )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()
        payload = {"password": password}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/password"+"?" + params
        return self._lr_object._put_json(url, payload)
    
    def getPassword(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/password"
        return self._lr_object._get_json(url, payload)
    
    def invalidateVerificationEmail(self, uid, verificationUrl = '', emailTemplate = ''):
        payload = '?apikey='+ self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret() + '&verificationUrl=' + verificationUrl + "&emailTemplate=" +emailTemplate
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/invalidateemail"
        return self._lr_object._put_json(url+payload, {})
    
    def getDeletedAccountByEmail(self, email):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(), 'email':email}
        url = self._lr_object.SECURE_API_URL + archivedEndpoint
        return self._lr_object._get_json(url, payload)
    
    def getDeletedAccountByPhone(self, phone):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(), 'phone':phone}
        url = self._lr_object.SECURE_API_URL + archivedEndpoint
        return self._lr_object._get_json(url, payload)
    
    def getDeletedAccountByUid(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(), 'uid':uid}
        url = self._lr_object.SECURE_API_URL + archivedEndpoint
        return self._lr_object._get_json(url, payload)
    
    def assignRole(self, uid, payload):
        """Put Assign Role( PUT )"""
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/role"+"?" + params
        return self._lr_object._put_json(url, payload)
    
    def getRoleByUid(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + uid + "/role"
        return self._lr_object._get_json(url, payload)
    
    def updateSecurityQuestion(self, uid, payload):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint  + uid + "?" + params
        return self._lr_object._put_json(url, payload)
    
    def getForgotPasswordToken(self, email):
        payload = {"email":email}
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + "forgot/token?" + params
        return self._lr_object._post_json(url, payload)
    
    def getEmailVerificationToken(self, email):
        payload = {"email":email}
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint + "verify/token?" + params
        return self._lr_object._post_json(url, payload)
    
    def getAccessToken(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'uid':uid}
        url = self._lr_object.SECURE_API_URL + accountEndpoint + "/access_token"
        return self._lr_object._get_json(url, payload)

    def resetPhoneIdVerification(self, uid):
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + accountEndpoint  + uid + "/invalidatephone?" + params
        return self._lr_object._put_json(url, {})

    def getBackupCodeByUid(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'uid':uid}
        url = self._lr_object.SECURE_API_URL + accountEndpoint  + "/2fa/backupcode"
        return self._lr_object._get_json(url, payload)

    def resetBackupCodeByUid(self, uid):
        payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'uid':uid}
        url = self._lr_object.SECURE_API_URL + accountEndpoint  + "/2fa/backupcode/reset"
        return self._lr_object._get_json(url, payload)
        
    
    class Profile:

        def __init__(self, lr_object):
            self._lr_object = lr_object
        
        def getByEmail(self, email):
            payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(), 'email':email}
            url = self._lr_object.SECURE_API_URL + accountEndpoint 
            return self._lr_object._get_json(url, payload)
    
        def getByUsername(self, username):
            payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(), 'username':username}
            url = self._lr_object.SECURE_API_URL + accountEndpoint
            return self._lr_object._get_json(url, payload)

        def getByPhone(self, phone):
            payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret(),'phone':phone}
            url = self._lr_object.SECURE_API_URL + accountEndpoint
            return self._lr_object._get_json(url, payload)
    
        def getByUid(self, uid):
            payload = {'apikey': self._lr_object._get_api_key(), 'apisecret': self._lr_object._get_api_secret()}
            url = self._lr_object.SECURE_API_URL + accountEndpoint + uid
            return self._lr_object._get_json(url, payload)

    class TwoFactor:

        def __init__(self, lr_object):
            self._lr_object = lr_object

        def removeAuthByUid(self, uid, authenticator):
            payload = {}
            payload[authenticator] = True
            params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+ self._lr_object._get_api_secret()+'&uid='+uid
            url = self._lr_object.SECURE_API_URL + accountEndpoint  + "2FA/authenticator?" + params
            return self._lr_object._delete_json(url, payload)
            



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################
from datetime import datetime

#Requires Python 2.6>
from collections import namedtuple
#Requires Python 2.7>
from importlib import import_module
import sys

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"

HEADERS = {'Accept': "application/json"}

from LoginRadius.sdk.accessToken import AccessToken
from LoginRadius.sdk.account import Account
from LoginRadius.sdk.authentication import Authentication
from LoginRadius.sdk.customObject import CustomObject
from LoginRadius.sdk.phoneAuthentication import PhoneAuthentication
from LoginRadius.sdk.webHook import WebHook
from LoginRadius.sdk.role import Role
from LoginRadius.sdk.socialLogin import SocialLogin
from LoginRadius.Exceptions import Exceptions

class LoginRadius:
    """
    LoginRadius Class. Use this to obtain social data and other information
    from the LoginRadius API. Requires Python 2.7 or greater.
    """

    API_KEY = None
    API_SECRET = None
    LIBRARY = None
    SECURE_API_URL = "https://api.loginradius.com/"

    def __init__(self):
        """
        Constructed when you want to retrieve social data with respect to the acquired token.
        :raise Exceptions.NoAPIKey: Raised if you did not set an API_KEY.
        :raise Exceptions.NoAPISecret: Raised if you did not set an API_SECRET.
        """
        
        self.error = {}
        self.sociallogin_raw = False;

        if not self.API_KEY:
            raise Exceptions.NoAPIKey

        if not self.API_SECRET:
            raise Exceptions.NoAPISecret
        self.SECURE_API_URL = "https://api.loginradius.com/"
        # Namedtuple for settings for each request and the api functions.
        self.settings = namedtuple("Settings", ['library', 'urllib', 'urllib2', 'json', 'requests'])
        
        self.accesstoken = self._get_accesstoken_tuple()
        self.account = self._get_account_tuple()
        self.authentication = self._get_authentication_tuple()
        self.customobject = self._get_customobject_tuple()
        self.phoneauthentication = self._get_phoneauthentication_tuple()
        self.webhook = self._get_webhook_tuple()
        self.role = self._get_role_tuple()
        self.sociallogin = self._get_sociallogin_tuple()

        # We prefer to use requests with the updated urllib3 module.
        try:
            from distutils.version import StrictVersion
            import requests

            if StrictVersion(requests.__version__) < StrictVersion("2.0"):
                raise Exceptions.RequestsLibraryDated(requests.__version__)
            else:
                self._settings("requests")

        # However, we can use urllib if there is no requests or it is outdated.
        except (ImportError, Exceptions.RequestsLibraryDated):
            self._settings("urllib2")

        # Well, something went wrong here.
        except:
            raise

        else:
            # Namedtuples for api, and user.
            self.accesstoken = self._get_accesstoken_tuple()

    #
    # Internal private functions
    #

    def _settings(self, library):
        """This sets the name tuple settings to whatever library you want. You may change this as you wish."""
        if LoginRadius.LIBRARY is not None:
            if LoginRadius.LIBRARY == "requests":
                self._set_requests()
            elif LoginRadius.LIBRARY == "urllib2":
                self._set_urllib2()
            else:
                raise Exceptions.InvalidLibrary(LoginRadius.LIBRARY)
        else:
            if library == "requests":
                self._set_requests()
            elif library == "urllib2":
                self._set_urllib2()
            else:
                raise Exceptions.InvalidLibrary(library)

    def _set_requests(self):
        """Change to the requests library to use."""
        self.settings.library = "requests"
        self.settings.requests = import_module("requests")
        self.settings.urllib2 = False

    def _set_urllib2(self):
        """Change to the requests urllib2 library to use."""
        if sys.version_info[0] == 2:
            self.settings.urllib2 = import_module("urllib2")
            self.settings.urllib = import_module("urllib")           
        else:          
            self.settings.urllib2 = import_module("urllib.request")
            self.settings.urllib = import_module("urllib.parse")
        self.settings.library = "urllib2"
        self.settings.requests = False
        self.settings.json = import_module("json")

    def _get_accesstoken_tuple(self):
        self.accessTokenAPI = AccessToken(self)
        """All the functions relative to the user with the token."""
        accessToken = namedtuple("AccessToken", ['exchange', 'validate','invalidate','refresh','getFacebookToken','getTwitterToken','getAccessTokenByGoogleJWT'])

        #Get methods
        accessToken.exchange = self.accessTokenAPI.exchange
        accessToken.validate = self.accessTokenAPI.validate
        accessToken.invalidate = self.accessTokenAPI.invalidate
        accessToken.refresh = self.accessTokenAPI.refresh
        accessToken.getFacebookToken = self.accessTokenAPI.getFacebookToken
        accessToken.getTwitterToken = self.accessTokenAPI.getTwitterToken
        return accessToken
    
    
    def _get_webhook_tuple(self):
        self.webhookAPI = WebHook(self)
        webhook = namedtuple("WebHook", ['subscribe', 'test', 'unsubscribe','getSubscribed'])
        webhook.subscribe = self.webhookAPI.subscribe;
        webhook.unsubscribe = self.webhookAPI.unsubscribe;
        webhook.getSubscribed = self.webhookAPI.getSubscribed;
        webhook.test = self.webhookAPI.test;
        return webhook;
    
    def _get_role_tuple(self):
        self.roleAPI = Role(self)
        self.rolePermissionAPI = Role.Permission(self)
        self.roleContextAPI = Role.Context(self)
        role = namedtuple("Role", ['create', 'get', 'remove','permission','unassignRoles'])
        role.permission =  namedtuple("Role_Permission", ['add', 'remove'])
        role.context =  namedtuple("Role_Context", ['get', 'add','delete','deleteRole', 'deletePermission'])
        role.create = self.roleAPI.create;
        role.get = self.roleAPI.get;
        role.remove = self.roleAPI.remove;
        role.unassignRoles = self.roleAPI.unassignRoles;
        role.permission.add = self.rolePermissionAPI.add;
        role.permission.remove = self.rolePermissionAPI.remove;
        role.context.get = self.roleContextAPI.get;
        role.context.add = self.roleContextAPI.add;
        role.context.delete = self.roleContextAPI.delete;
        role.context.deleteRole = self.roleContextAPI.deleteRole;
        role.context.deletePermission = self.roleContextAPI.deletePermission;
        return role;
    
    def _get_sociallogin_tuple(self):
        self.socialloginAPI = SocialLogin(self)
        user = namedtuple("User", ['profile', 'photo', 'check_in', 'audio', 'album', 'video',
                                   'contacts', 'status', 'group', 'post', 'event', 'mention',
                                   'company', 'following', 'page', 'like', 'status_update', 'direct_message','get_message','get_status_update'])
        if self.sociallogin_raw:
            user.profile = self.socialloginAPI.get_user_profile_raw;
        else:
            user.profile = self.socialloginAPI.get_user_profile;
        if self.sociallogin_raw:
            user.photo = self.socialloginAPI.get_photo_raw;
        else:
            user.photo = self.socialloginAPI.get_photo;
        if self.sociallogin_raw:
            user.check_in = self.socialloginAPI.get_checkin_raw;
        else:
            user.check_in = self.socialloginAPI.get_checkin;
        if self.sociallogin_raw:
            user.audio = self.socialloginAPI.get_audio_raw;
        else:
            user.audio = self.socialloginAPI.get_audio;
        if self.sociallogin_raw:
            user.album = self.socialloginAPI.get_album_raw;
        else:
            user.album = self.socialloginAPI.get_album;
        if self.sociallogin_raw:
            user.video = self.socialloginAPI.get_video_raw;
        else:
            user.video = self.socialloginAPI.get_video;
        if self.sociallogin_raw:
            user.contacts = self.socialloginAPI.get_contacts_raw;
        else:
            user.contacts = self.socialloginAPI.get_contacts;
        if self.sociallogin_raw:
            user.status = self.socialloginAPI.get_status_raw;
        else:
            user.status = self.socialloginAPI.get_status;
        if self.sociallogin_raw:
            user.group = self.socialloginAPI.get_group_raw;
        else:
            user.group = self.socialloginAPI.get_group;
        if self.sociallogin_raw:
            user.profile = self.socialloginAPI.get_user_profile_raw;
        else:
            user.profile = self.socialloginAPI.get_user_profile;
        if self.sociallogin_raw:
            user.post = self.socialloginAPI.get_post_raw;
        else:
            user.post = self.socialloginAPI.get_post;
        if self.sociallogin_raw:
            user.event = self.socialloginAPI.get_event_raw;
        else:
            user.event = self.socialloginAPI.get_event;
        if self.sociallogin_raw:
            user.mention = self.socialloginAPI.get_mention_raw;
        else:
            user.mention = self.socialloginAPI.get_mention;
        if self.sociallogin_raw:
            user.company = self.socialloginAPI.get_company_raw;
        else:
            user.company = self.socialloginAPI.get_company;
        if self.sociallogin_raw:
            user.following = self.socialloginAPI.get_following_raw;
        else:
            user.following = self.socialloginAPI.get_following;
        if self.sociallogin_raw:
            user.activity = self.socialloginAPI.get_activity_raw;
        else:
            user.activity = self.socialloginAPI.get_activity;
        if self.sociallogin_raw:
            user.page = self.socialloginAPI.get_page_raw;
        else:
            user.page = self.socialloginAPI.get_page;
        if self.sociallogin_raw:
            user.like = self.socialloginAPI.get_like_raw;
        else:
            user.like = self.socialloginAPI.get_like;
        user.get_status_update = self.socialloginAPI.get_status_update;
        user.status_update = self.socialloginAPI.status_update;
        user.direct_message = self.socialloginAPI.direct_message;
        user.message = self.socialloginAPI.get_message;
            
        return user;
    
    def _get_phoneauthentication_tuple(self):
        self.phoneauthenticationAPI = PhoneAuthentication(self)
        self.phoneauthenticationOTPAPI = PhoneAuthentication.OTP(self)
        phoneauthentication = namedtuple("PhoneAuthentication", ['register', 'login', 'update', 'getPhoneAvailable', 'forgotPassword','resetPassword'])
        phoneauthentication.otp = namedtuple("PhoneAuthentication_OTP", ['resend', 'resendByToken', 'verify', 'verifyByToken', 'send'])
        phoneauthentication.register = self.phoneauthenticationAPI.register;
        phoneauthentication.login = self.phoneauthenticationAPI.login;
        phoneauthentication.update = self.phoneauthenticationAPI.update;
        phoneauthentication.getPhoneAvailable = self.phoneauthenticationAPI.getPhoneAvailable;
        phoneauthentication.forgotPassword = self.phoneauthenticationAPI.forgotPassword;
        phoneauthentication.resetPassword = self.phoneauthenticationAPI.resetPassword;
        phoneauthentication.otp.resend = self.phoneauthenticationOTPAPI.resend;
        phoneauthentication.otp.verify = self.phoneauthenticationOTPAPI.verify;
        phoneauthentication.otp.verifyByToken = self.phoneauthenticationOTPAPI.verifyByToken;
        phoneauthentication.otp.resendByToken = self.phoneauthenticationOTPAPI.resendByToken;
        phoneauthentication.otp.send = self.phoneauthenticationOTPAPI.send;
        return phoneauthentication;
        
        
    def _get_customobject_tuple(self):
        self.customobjectAPI = CustomObject(self)
        customobject = namedtuple("CustomObject", ['create', 'update', 'getByUID', 'getByObjectRecordId', 'remove'])
        customobject.create = self.customobjectAPI.create;
        customobject.update = self.customobjectAPI.update;
        customobject.getByUID = self.customobjectAPI.getByUID;
        customobject.getByObjectRecordId = self.customobjectAPI.getByObjectRecordId;
        customobject.remove = self.customobjectAPI.remove;
        return customobject
        
    
    def _get_authentication_tuple(self):
        self.authenticationAPI = Authentication(self)
        self.authenticationLoginAPI = Authentication.Login(self)
        self.authenticationProfileAPI = Authentication.Profile(self)
        self.authenticationCustomObjectAPI = Authentication.CustomObject(self)
        self.authenticationTwoFactorAPI = Authentication.TwoFactor(self)
        authentication = namedtuple("Authentication", ['getBackupCode','resetBackupCode','register', 'getServerTime','captchaRegister', 'resendEmailVerification', 'removeAccountByEmailConfirmation', 'forgotPassword', 'resetPassword',
                                                'changePassword','addEmail','removeEmail','getVerifyEmail','getCheckEmail','changeUsername','checkUsername',
                                                'accountLink','accountUnlink','getSocialProfile','tokenValidate','tokenInvalidate','resetPasswordbySecurityQuestion', 'updateSecurityQuestionByAccessToken',
                                                       'securityQuestionByToken','securityQuestionByEmail','securityQuestionByUsername','securityQuestionByPhone'])
        authentication.login = namedtuple("Authentication_Login", ['byBackupCode','byOTP', 'byEmail', 'byUsername','autoLoginByUsername','autoLoginByEmail','ping',
                                                                   'oneClickSignInByEmail','oneClickSignInVerification','oneClickSignInByUsername'])
        authentication.profile = namedtuple("Authentication_Profile", ['getByToken','updateByToken'])
        authentication.customobject = namedtuple("Authentication_CustomObject", ['create','update','getByID','getByToken', 'delete'])
        authentication.twofactor = namedtuple("Authentication_TwoFactor", ['byToken','phoneLogin','emailLogin','usernameLogin','updatePhone','verifyGoogleAuth','updatePhoneByToken',
                                                'googleAuthByToken','removeAuthByToken'])
        authentication.register = self.authenticationAPI.register;
        authentication.getBackupCode = self.authenticationAPI.getBackupCode;
        authentication.resetBackupCode = self.authenticationAPI.resetBackupCode;
        authentication.getServerTime = self.authenticationAPI.getServerTime;
        authentication.captchaRegister = self.authenticationAPI.captchaRegister;
        authentication.resendEmailVerification = self.authenticationAPI.resendEmailVerification;
        authentication.removeAccountByEmailConfirmation = self.authenticationAPI.removeAccountByEmailConfirmation;
        authentication.forgotPassword = self.authenticationAPI.forgotPassword;
        authentication.resetPassword = self.authenticationAPI.resetPassword;
        authentication.resetPasswordbySecurityQuestion = self.authenticationAPI.resetPasswordbySecurityQuestion;
        authentication.updateSecurityQuestionByAccessToken = self.authenticationAPI.updateSecurityQuestionByAccessToken;
        authentication.changePassword = self.authenticationAPI.changePassword;
        authentication.addEmail = self.authenticationAPI.addEmail;
        authentication.removeEmail = self.authenticationAPI.removeEmail;
        authentication.getVerifyEmail = self.authenticationAPI.getVerifyEmail;
        authentication.getCheckEmail = self.authenticationAPI.getCheckEmail;
        authentication.changeUsername = self.authenticationAPI.changeUsername;
        authentication.checkUsername = self.authenticationAPI.checkUsername;
        authentication.accountLink = self.authenticationAPI.accountLink;
        authentication.accountUnlink = self.authenticationAPI.accountUnlink;
        authentication.getSocialProfile = self.authenticationAPI.getSocialProfile;
        authentication.tokenValidate = self.authenticationAPI.tokenValidate;
        authentication.tokenInvalidate = self.authenticationAPI.tokenInvalidate;
        authentication.securityQuestionByToken = self.authenticationAPI.securityQuestionByToken;
        authentication.securityQuestionByEmail = self.authenticationAPI.securityQuestionByEmail;
        authentication.securityQuestionByUsername = self.authenticationAPI.securityQuestionByUsername;
        authentication.securityQuestionByPhone = self.authenticationAPI.securityQuestionByPhone;
        authentication.login.byEmail = self.authenticationLoginAPI.byEmail;
        authentication.login.byBackupCode = self.authenticationLoginAPI.byBackupCode;
        authentication.login.byOTP = self.authenticationLoginAPI.byOTP;
        authentication.login.byUsername = self.authenticationLoginAPI.byUsername;
        authentication.login.autoLoginByUsername = self.authenticationLoginAPI.autoLoginByUsername;
        authentication.login.autoLoginByEmail = self.authenticationLoginAPI.autoLoginByEmail;
        authentication.login.ping = self.authenticationLoginAPI.ping;
        authentication.login.oneClickSignInByEmail = self.authenticationLoginAPI.oneClickSignInByEmail;
        authentication.login.oneClickSignInByUsername = self.authenticationLoginAPI.oneClickSignInByUsername;
        authentication.login.oneClickSignInVerification = self.authenticationLoginAPI.oneClickSignInVerification;
        authentication.profile.getByToken = self.authenticationProfileAPI.getByToken;
        authentication.profile.updateByToken = self.authenticationProfileAPI.updateByToken;
        authentication.customobject.create = self.authenticationCustomObjectAPI.create;
        authentication.customobject.update = self.authenticationCustomObjectAPI.update;
        authentication.customobject.getByID = self.authenticationCustomObjectAPI.getByID;
        authentication.customobject.delete = self.authenticationCustomObjectAPI.delete;
        authentication.customobject.getByToken = self.authenticationCustomObjectAPI.getByToken;
        authentication.twofactor.byToken = self.authenticationTwoFactorAPI.byToken;
        authentication.twofactor.phoneLogin = self.authenticationTwoFactorAPI.phoneLogin;
        authentication.twofactor.emailLogin = self.authenticationTwoFactorAPI.emailLogin;
        authentication.twofactor.usernameLogin = self.authenticationTwoFactorAPI.usernameLogin;
        authentication.twofactor.updatePhone = self.authenticationTwoFactorAPI.updatePhone;
        authentication.twofactor.verifyGoogleAuth = self.authenticationTwoFactorAPI.verifyGoogleAuth;
        authentication.twofactor.updatePhoneByToken = self.authenticationTwoFactorAPI.updatePhoneByToken;
        authentication.twofactor.googleAuthByToken = self.authenticationTwoFactorAPI.googleAuthByToken;
        authentication.twofactor.removeAuthByToken = self.authenticationTwoFactorAPI.removeAuthByToken;
        return authentication;
        
    def _get_account_tuple(self):
        self.accountProfileAPI = Account.Profile(self)
        self.accountAPI = Account(self)
        self.accountTwoFactorAPI = Account.TwoFactor(self)
        account = namedtuple("Account", ['updateSecurityQuestion','assignRole','getRoleByUid','create', 'update', 'remove', 'setPassword',
                                         'getPassword','invalidateVerificationEmail','getDeletedAccountByEmail','getDeletedAccountByPhone',
                                         'getDeletedAccountByUid','getForgotPasswordToken','getEmailVerificationToken','getAccessToken','resetPhoneIdVerification',
                                         'getBackupCodeByUid','resetBackupCodeByUid'])
        account.profile = namedtuple("Account_Profile", ['getByEmail','getByUsername','getByPhone','getByUid'])
        account.twofactor = namedtuple("Account_TwoFactor", ['removeAuthByUid'])
        account.profile.getByEmail = self.accountProfileAPI.getByEmail
        account.twofactor.removeAuthByUid = self.accountTwoFactorAPI.removeAuthByUid
        account.create=  self.accountAPI.create
        account.getBackupCodeByUid=  self.accountAPI.getBackupCodeByUid
        account.resetBackupCodeByUid=  self.accountAPI.resetBackupCodeByUid
        account.updateSecurityQuestion=  self.accountAPI.updateSecurityQuestion
        account.update=  self.accountAPI.update
        account.remove=  self.accountAPI.remove
        account.setPassword=  self.accountAPI.setPassword
        account.getPassword=  self.accountAPI.getPassword
        account.resetPhoneIdVerification=  self.accountAPI.resetPhoneIdVerification
        account.invalidateVerificationEmail=  self.accountAPI.invalidateVerificationEmail
        account.getDeletedAccountByEmail=  self.accountAPI.getDeletedAccountByEmail
        account.getDeletedAccountByPhone=  self.accountAPI.getDeletedAccountByPhone
        account.getDeletedAccountByUid=  self.accountAPI.getDeletedAccountByUid
        account.getForgotPasswordToken=  self.accountAPI.getForgotPasswordToken
        account.getEmailVerificationToken=  self.accountAPI.getEmailVerificationToken
        account.getAccessToken=  self.accountAPI.getAccessToken
        account.assignRole=  self.accountAPI.assignRole
        account.getRoleByUid=  self.accountAPI.getRoleByUid
        account.profile.getByEmail = self.accountProfileAPI.getByEmail
        account.profile.getByUsername = self.accountProfileAPI.getByUsername
        account.profile.getByPhone = self.accountProfileAPI.getByPhone
        account.profile.getByUid = self.accountProfileAPI.getByUid
        return account


    def _get_json(self, url, payload):
        """Get JSON from LoginRadius"""
        if self.settings.requests:
            r = self.settings.requests.get(url, params=payload, headers=HEADERS)
            return self._process_result(r.json())
        else:
            payload = self.settings.urllib.urlencode(payload)
            r = self.settings.urllib2.Request(url + "?" + payload)
            r.add_header('Accept', HEADERS['Accept'])
            try:
                data = self.settings.urllib2.urlopen(r)
            except self.settings.urllib2.HTTPError:
                raise
            import codecs
            reader = codecs.getreader("utf-8")
            return self._process_result(self.settings.json.load(reader(data)))

    def _post_json(self, url, payload):
        return self.__submit_json('post', url, payload)
    def _put_json(self, url, payload):
        return self.__submit_json('put', url, payload)
    def _delete_json(self, url, payload):
        return self.__submit_json('delete', url, payload)
    def __submit_json(self, method, url, payload):
        if self.settings.requests:
            import json
            HEADERS = {'content-type': 'application/json'}
            if method == 'put':
                r = self.settings.requests.put(url, data=json.dumps(payload), headers=HEADERS)
            elif method == 'delete':
                r = self.settings.requests.delete(url, data=json.dumps(payload), headers=HEADERS)
            else:
                r = self.settings.requests.post(url, data=json.dumps(payload), headers=HEADERS)
            return self._process_result(r.json())

        else:
            import json
            data = json.dumps(payload)
            if sys.version_info[0] == 3:
                data = data.encode('ascii')
            HEADERS = {'content-type': 'application/json'}
            r = self.settings.urllib2.Request(url, data, {'Content-Type': 'application/json'})
            if method == 'put' or method == 'delete':
                r.get_method = lambda: method
            for key, value in HEADERS.items():
                r.add_header(key, value)
            try:
                result = self.settings.urllib2.urlopen(r)
            except self.settings.urllib2.HTTPError:
                raise
            import codecs
            reader = codecs.getreader("utf-8")    
            return self._process_result(self.settings.json.load(reader(result)))
        

    def _get_api_key(self):
        return self.API_KEY

    def _get_api_secret(self):
        return self.API_SECRET

    def _process_result(self, result):
        """Anything we need to parse or look for. In this case, just the ErrorCode"""
        if "ErrorCode" in result:
            self._process_error(result)
        else:
            return result

    def _process_error(self, result):
        """If there is an errorCode, let's figure out which one and raise the corresponding exception."""
        self.error = result
        if result['ErrorCode'] == 901:
            raise Exceptions.APIKeyInvalid
        elif result['ErrorCode'] == 902:
            raise Exceptions.APISecretInvalid
        elif result['ErrorCode'] == 903:
            raise Exceptions.InvalidRequestToken
        elif result['ErrorCode'] == 904:
            raise Exceptions.RequestTokenExpired
        elif result['ErrorCode'] == 905:
            raise Exceptions.InvalidAccessToken
        elif result['ErrorCode'] == 906:
            raise Exceptions.TokenExpired(self.access.expire)
        elif result['ErrorCode'] == 907:
            raise Exceptions.ParameterMissing
        elif result['ErrorCode'] == 908:
            raise Exceptions.ParameterNotFormatted
        elif result['ErrorCode'] == 909:
            raise Exceptions.FeatureNotSupported
        elif result['ErrorCode'] == 910:
            raise Exceptions.EndPointNotSupported
        else:
            raise Exceptions.UnknownJsonError(result)


    #
    # Public functions
    #

    def change_library(self, library):
        self._settings(library)



#!/usr/bin/python
#################################################
# Class for Social Authentication               #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified Social API. It contains  #
# functions for Social Authentication with User #
# Profile Data (Basic and Extended).            #
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

SECURE_API_URL = "https://api.loginradius.com/"
socialLoginEndpoint ="/api/v2/";

class SocialLogin():
    """Where all the API commands can be invoked locally."""

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    #
    # Read permissions
    #

    def get_user_profile(self, access_token):
        """Retrieve basic profile information."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint +"userprofile/"
        return self._lr_object._get_json(url, payload)

    def get_user_profile_raw(self, access_token):
        """Retrieve basic profile information but unformatted based on the provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "userprofile/raw/"
        return self._lr_object._get_json(url, payload)

    def get_photo(self, access_token, album_id=''):
        """Get photos based on the album_id retrieved."""
        payload = {'access_token': access_token, 'albumid': album_id}
        url = SECURE_API_URL + socialLoginEndpoint + "photo/"
        return self._lr_object._get_json(url, payload)

    def get_photo_raw(self, access_token, album_id=''):
        """Get photos based on the album_id retrieved but unformatted based on the provider."""
        payload = {'access_token': access_token, 'albumid': album_id}
        url = SECURE_API_URL + socialLoginEndpoint + "photo/raw/"
        return self._lr_object._get_json(url, payload)

    def get_checkin(self, access_token):
        """Get check ins from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "checkin/"
        return self._lr_object._get_json(url, payload)

    def get_checkin_raw(self, access_token):
        """Get check ins but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "checkin/raw/"
        return self._lr_object._get_json(url, payload)

    def get_album(self, access_token):
        """Get albums from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "album/"
        return self._lr_object._get_json(url, payload)

    def get_album_raw(self, access_token):
        """Get albums from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "album/raw/"
        return self._lr_object._get_json(url, payload)

    def get_audio(self, access_token):
        """Get audio from the profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "audio/"
        return self._lr_object._get_json(url, payload)

    def get_audio_raw(self, access_token):
        """Get audio from the profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "audio/raw/"
        return self._lr_object._get_json(url, payload)

    def get_video(self, access_token):
        """Get videos from the profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "video/"
        return self._lr_object._get_json(url, payload)

    def get_video_raw(self, access_token):
        """Get videos from the profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "video/raw/"
        return self._lr_object._get_json(url, payload)

    def get_contacts(self, access_token, next_cursor=''):
        """Get a list of contacts from the profile."""
        payload = {'access_token': access_token, 'nextcursor': next_cursor}
        url = SECURE_API_URL + socialLoginEndpoint + "contact/"
        return self._lr_object._get_json(url, payload)

    def get_contacts_raw(self, access_token, next_cursor=''):
        """Get a list of contacts from the profile but in raw format based on provider."""
        payload = {'access_token': access_token, 'nextcursor': next_cursor}
        url = SECURE_API_URL + socialLoginEndpoint + "contact/raw/"
        return self._lr_object._get_json(url, payload)

    def get_status(self, access_token):
        """Get status updates from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "status/"
        return self._lr_object._get_json(url, payload)

    def get_status_raw(self, access_token):
        """Get status updates from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "status/raw/"
        return self._lr_object._get_json(url, payload)

    def get_group(self, access_token):
        """Get group data from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "group/"
        return self._lr_object._get_json(url, payload)

    def get_group_raw(self, access_token):
        """Get group data from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "group/raw/"
        return self._lr_object._get_json(url, payload)

    def get_post(self, access_token):
        """Get posts from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "post/"
        return self._lr_object._get_json(url, payload)

    def get_post_raw(self, access_token):
        """Get posts from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "post/raw/"
        return self._lr_object._get_json(url, payload)

    def get_event(self, access_token):
        """Get events from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "event/"
        return self._lr_object._get_json(url, payload)

    def get_event_raw(self, access_token):
        """Get events from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "event/raw/"
        return self._lr_object._get_json(url, payload)

    def get_mention(self, access_token):
        """Get mentions from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "mention/"
        return self._lr_object._get_json(url, payload)

    def get_mention_raw(self, access_token):
        """Get mentions from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "mention/raw/"
        return self._lr_object._get_json(url, payload)

    def get_company(self, access_token):
        """Get company from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "company/"
        return self._lr_object._get_json(url, payload)

    def get_company_raw(self, access_token):
        """Get company from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "company/raw/"
        return self._lr_object._get_json(url, payload)

    def get_following(self, access_token):
        """Get following/followers from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "following/"
        return self._lr_object._get_json(url, payload)

    def get_following_raw(self, access_token):
        """Get following/followers from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "following/raw/"
        return self._lr_object._get_json(url, payload)

    def get_activity(self, access_token):
        """Get activity from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "activity/"
        return self._lr_object._get_json(url, payload)

    def get_activity_raw(self, access_token):
        """Get activity from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "activity/raw/"
        return self._lr_object._get_json(url, payload)

    def get_page(self, access_token, page_name):
        """Get page information from profile."""
        payload = {'access_token': access_token, 'pagename': page_name}
        url = SECURE_API_URL + socialLoginEndpoint + "page/"
        return self._lr_object._get_json(url, payload)

    def get_page_raw(self, access_token, page_name):
        """Get page information from profile but in raw format based on provider."""
        payload = {'access_token': access_token, 'pagename': page_name}
        url = SECURE_API_URL + socialLoginEndpoint + "page/raw/"
        return self._lr_object._get_json(url, payload)

    def get_like(self, access_token):
        """Get likes from profile."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "like/"
        return self._lr_object._get_json(url, payload)

    def get_like_raw(self, access_token):
        """Get likes from profile but in raw format based on provider."""
        payload = {'access_token': access_token}
        url = SECURE_API_URL + socialLoginEndpoint + "like/raw/"
        return self._lr_object._get_json(url, payload)
    
    def get_message(self, access_token, to, subject, message):
        """Get messages from profile."""
        payload = {'access_token': access_token, 'to':to,'subject':subject,'message':message}
        url = SECURE_API_URL + socialLoginEndpoint + "message/js/"
        return self._lr_object._get_json(url, payload)

    def get_status_update(self, access_token, status, title='', url='', imageurl='', caption='', description=''):
        """
        Perform a status update on the profile on behalf of the user.
        Some of these arguments may be ignored depending on the provider.
        For what is and is not supported, please refer to:
        http://www.loginradius.com/datapoints
        """
        payload = '?access_token='+ access_token + '&status='+ status + '&title='+ title + '&url=' + url + '&imageurl=' + imageurl + '&caption=' + caption + '&description=' + description
        url = SECURE_API_URL + socialLoginEndpoint + "status/js"
        return self._lr_object._get_json(url+payload, {})

    #
    #Write Permissions
    #

    def status_update(self, access_token, status, title='', url='', imageurl='', caption='', description=''):
        """
        Perform a status update on the profile on behalf of the user.
        Some of these arguments may be ignored depending on the provider.
        For what is and is not supported, please refer to:
        http://www.loginradius.com/datapoints
        """
        payload = '?access_token='+ access_token + '&status='+ status + '&title='+ title + '&url=' + url + '&imageurl=' + imageurl + '&caption=' + caption + '&description=' + description
        url = SECURE_API_URL + socialLoginEndpoint + "status/"
        return self._lr_object._post_json(url+payload, {})

    def direct_message(self, access_token, to, subject, message):
        """Direct message another user on behalf of this user."""
        payload = '?access_token=' + access_token + '&to=' + to + '&subject=' + subject + '&message=' + message
        url = SECURE_API_URL + socialLoginEndpoint + "message/"
        return self._lr_object._post_json(url+payload, {})





from pbkdf2 import PBKDF2
from Crypto.Cipher import AES
import base64
import datetime
import hashlib
import binascii
import sys

class SOTT:
    CONST_INITVECTOR="tu89geji340t89u2"
    CONST_KEYSIZE=256

    def __init__(self, lr_object):
            self._lr_object = lr_object
            self.bs = 16
    
    def encrypt(self, time = '10', getLRserverTime = False):
        if getLRserverTime:
            from LoginRadius.sdk.authentication import Authentication
            authenticationAPI = Authentication(self._lr_object)
            result = authenticationAPI.getServerTime(time)
            if result.get('Sott') is not None:
                Sott = result.get('Sott')
                for timeKey,val in Sott.items():
                    if timeKey == 'StartTime':
                        now = val;
                    if timeKey == 'EndTime':
                        now_plus_10m = val;                   
            else:
                now = datetime.datetime.utcnow()
                now  = now - datetime.timedelta(minutes=5)
                now_plus_10m=now+datetime.timedelta(minutes=10)
                now = now.strftime("%Y/%m/%d %I:%M:%S")
                now_plus_10m = now_plus_10m.strftime("%Y/%m/%d %I:%M:%S")
     
                
        else:
            now = datetime.datetime.utcnow()
            now  = now - datetime.timedelta(minutes=5)
            now_plus_10m=now+datetime.timedelta(minutes=10)
            now = now.strftime("%Y/%m/%d %I:%M:%S")
            now_plus_10m = now_plus_10m.strftime("%Y/%m/%d %I:%M:%S")
            
        plaintext=now+"#"+self._lr_object._get_api_key()+"#"+now_plus_10m
        padding = 16 - (len(plaintext) % 16)
        if sys.version_info[0] == 3:
            plaintext += (bytes([padding])*padding).decode()
        else:
            plaintext += (chr(padding)*padding).decode()
        
        salt="\0\0\0\0\0\0\0\0"
        
        cipher_key=PBKDF2(self._lr_object._get_api_secret(), salt,10000).read(self.CONST_KEYSIZE//8)
        
        cipher=AES.new(cipher_key, AES.MODE_CBC, self.CONST_INITVECTOR)
        
        base64cipher=base64.b64encode(cipher.encrypt(plaintext))
        
        md5=hashlib.md5()
        md5.update(base64cipher.decode('utf8').encode('ascii'))
        return base64cipher.decode('utf-8').replace("+","%2B")+"*"+binascii.hexlify(md5.digest()).decode('ascii')
    
    @staticmethod
    def _unpad(s):
        return s[:-ord(s[len(s)-1:])]

    def decrypt(self,cipher):
        base64token=cipher[:cipher.index("*")].replace("%2B","+");
        cipherBytes=base64.b64decode(base64token)
        salt="\0\0\0\0\0\0\0\0"
        cipher_key=PBKDF2(self._lr_object._get_api_secret(), salt,10000).read(self.CONST_KEYSIZE//8)
        cipher=AES.new(cipher_key, AES.MODE_CBC, self.CONST_INITVECTOR)
        return self._unpad(cipher.decrypt(cipherBytes[AES.block_size:])).decode('utf-8',errors="ignore")



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


restHookEndpoint = "/api/v2/"

class RestHook:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def subscribe(self, target_url, event):
        payload ={'target_url':target_url,'event':event}
        params = 'api_key='+self._lr_object._get_api_key() + '&api_secret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + restHookEndpoint  + "resthook/subscribe?" + params
        return self._lr_object._post_json(url, payload)
    
    def aggregationQueryData(self, fromKey, to, first_data_point, stats_type):
        payload ={'firstDatapoint':first_data_point,'statsType':stats_type}
        params = 'apikey='+self._lr_object._get_api_key() + '&apisecret='+self._lr_object._get_api_secret()+'&from='+fromKey+'&to='+to
        url = self._lr_object.SECURE_API_URL + restHookEndpoint  + "insights?" + params
        return self._lr_object._post_json(url, payload)
    
    def userList(self, fromKey, select, where, orderby, skip, limit):
        payload ={'from':fromKey,'select':select,'where':where,'orderby':orderby,'skip':skip,'limit':limit}
        params = 'key='+self._lr_object._get_api_key() + '&secret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + restHookEndpoint  + "resthook/identity?" + params
        return self._lr_object._post_json(url, payload)
    
    def settings(self):
        payload = {'api_key': self._lr_object._get_api_key(), 'api_secret': self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + restHookEndpoint  + "resthook/test"
        return self._lr_object._get_json(url, payload)
    
    def unsubscribe(self, target_url):
        payload ={'target_url':target_url}
        params = 'api_key='+self._lr_object._get_api_key() + '&api_secret='+self._lr_object._get_api_secret()
        url = self._lr_object.SECURE_API_URL + restHookEndpoint  + "resthook/unsubscribe?" + params
        return self._lr_object._delete_json(url, payload)

    def getSubscribed(self, event):
        payload = {'api_key': self._lr_object._get_api_key(), 'api_secret':self._lr_object._get_api_secret(), 'event': event}
        url = self._lr_object.SECURE_API_URL + restHookEndpoint + "resthook/subscription"
        return self._lr_object._get_json(url, payload)

    def getFields(self):
        payload = {'api_key': self._lr_object._get_api_key(), 'api_secret':self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + restHookEndpoint + "resthook/fields"
        return self._lr_object._get_json(url, payload)



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


phoneAuthEndpoint = "/identity/v2/auth/"

class PhoneAuthentication:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def register(self, payload, verificationUrl = '', smsTemplate  = '', getLRServerTime = False):
        from LoginRadius.sdk.sott import SOTT
        sottAPI = SOTT(self._lr_object)
        
        sott = sottAPI.encrypt('10', getLRServerTime)
        params = 'apikey='+self._lr_object._get_api_key() + '&sott='+sott+'&verificationUrl='+ verificationUrl + '&smsTemplate='  +smsTemplate
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "register?" + params
        return self._lr_object._post_json(url, payload)
    
    def login(self, phone, password, loginUrl = '', smsTemplate = ''):
        payload = {'apikey': self._lr_object._get_api_key(), 'phone': phone,'password':password,'loginUrl':loginUrl,'smsTemplate':smsTemplate}
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "login"
        return self._lr_object._get_json(url, payload)
    
    def update(self, phone, access_token, smsTemplate = ''):
        params = 'apikey='+self._lr_object._get_api_key() + '&access_token='+ access_token + '&smsTemplate='  +smsTemplate
        payload = {'phone': phone}
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone?" + params
        return self._lr_object._put_json(url, payload)

    def getPhoneAvailable(self, phone):
        payload = {'apikey': self._lr_object._get_api_key(), 'phone': phone}
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone"
        return self._lr_object._get_json(url, payload)
    
    def forgotPassword(self, phone, smsTemplate = ''):
        payload = {"phone":phone}
        params = 'apikey='+self._lr_object._get_api_key() + '&smsTemplate='  +smsTemplate
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "password/otp?" + params
        return self._lr_object._post_json(url, payload)
    
    def resetPassword(self, phone, otp, password, smsTemplate = ''):
        payload = {"phone": phone,"otp": otp,"password": password}
        params = 'apikey='+self._lr_object._get_api_key() + '&smsTemplate='  +smsTemplate
        url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "password/otp?" + params
        return self._lr_object._put_json(url, payload)

    class OTP:
        def __init__(self, lr_object):
            """
            :param lr_object: this is the reference to the parent LoginRadius object.
            """
            self._lr_object = lr_object
            
        def resend(self, phone, smsTemplate = ''):
            params = 'apikey='+self._lr_object._get_api_key() + '&smsTemplate='  +smsTemplate
            payload = {"phone": phone}
            url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone/otp?" + params
            return self._lr_object._post_json(url, payload)
        
        def resendByToken(self, phone, access_token, smsTemplate = ''):
            params = 'apikey='+self._lr_object._get_api_key() + '&access_token='+access_token+ '&smsTemplate='  +smsTemplate
            payload = {"phone": phone}
            url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone/otp?" + params
            return self._lr_object._post_json(url, payload)

        def verify(self, phone, otp, smsTemplate = ''):
            payload = {"phone": phone}
            params = 'apikey='+self._lr_object._get_api_key() + '&otp='+otp+'&smsTemplate='  +smsTemplate
            url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone/otp?" + params
            return self._lr_object._put_json(url, payload)
        
        def verifyByToken(self, phone, access_token, otp, smsTemplate = ''):
            payload = {"phone": phone}
            params = 'apikey='+self._lr_object._get_api_key() + '&access_token='+access_token+'&otp='+otp+'&smsTemplate='  +smsTemplate
            url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "phone/otp?" + params
            return self._lr_object._put_json(url, payload)

        def send(self, phone, smsTemplate = ''):
            payload = {'apikey': self._lr_object._get_api_key(), 'phone': phone, 'smsTemplate':smsTemplate}
            url = self._lr_object.SECURE_API_URL + phoneAuthEndpoint  + "login/otp"
            return self._lr_object._get_json(url, payload)

        
        



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2017-2018 LoginRadius Inc.          #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################

__author__ = "LoginRadius"
__copyright__ = "Copyright 2017-2018, LoginRadius"
__email__ = "developers@loginradius.com"
__status__ = "Production"
__version__ = "3.0"


tokenEndpoint = "/api/v2/access_token"

class AccessToken:
    
    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object
        
    def exchange(self, token):
        """The Access Token API is used to get the LoginRadius access token after authentication. It will be valid for the specific duration of time specified in the response"""
        payload = {'token': token, 'secret': self._lr_object._get_api_secret()}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint
        return self._lr_object._get_json(url, payload)
    
    def validate(self, access_token):
        """Token Validate( GET )"""
        payload = {'key': self._lr_object._get_api_key(), 'secret': self._lr_object._get_api_secret(),'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint + "/Validate"
        return self._lr_object._get_json(url, payload)
    
    def invalidate(self, access_token):
        """Token Validate( GET )"""
        payload = {'key': self._lr_object._get_api_key(), 'secret': self._lr_object._get_api_secret(),'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint + "/invalidate"
        return self._lr_object._get_json(url, payload)

    def refresh(self, access_token):
        """Token Validate( GET )"""
        payload = {'key': self._lr_object._get_api_key(), 'secret': self._lr_object._get_api_secret(),'access_token':access_token}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint + "/refresh"
        return self._lr_object._get_json(url, payload)
    
    def getFacebookToken(self, fb_access_token):
        """Token Validate( GET )"""
        payload = {'key': self._lr_object._get_api_key(),'fb_access_token':fb_access_token}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint + "/facebook"
        return self._lr_object._get_json(url, payload)

    def getTwitterToken(self, tw_access_token, tw_token_secret):
        """Token Validate( GET )"""
        payload = {'key': self._lr_object._get_api_key(),'tw_access_token':tw_access_token, 'tw_token_secret':tw_token_secret}
        url = self._lr_object.SECURE_API_URL + tokenEndpoint + "/twitter"
        return self._lr_object._get_json(url, payload)
        
        



from distutils.core import setup
setup(
    name = 'LoginRadius-v2',
    version= '3.0',
    packages=["LoginRadius","LoginRadius.sdk"],
    description = 'Social Login and User Registration for Python.',
	long_description = open('README.rst').read() + '\n\n' + open('HISTORY.rst').read(),
    author='LoginRadius',
    author_email='developers@loginradius.com',
    url='http://loginradius.com/',
    classifiers=['Programming Language :: Python', 'Programming Language :: Python :: 2.7','Programming Language :: Python :: 3.4',
                 'Programming Language :: Python :: 3.6','Operating System :: OS Independent', 'License :: OSI Approved :: MIT License',
                 'Development Status :: 5 - Production/Stable', 'Intended Audience :: Developers',
                 'Topic :: Internet', 'Topic :: Internet :: WWW/HTTP',
                 'Topic :: Software Development :: Libraries :: Python Modules']
)
